summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/aligntoolbar.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/aligntoolbar.cpp')
-rw-r--r--umbrello/umbrello/aligntoolbar.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/aligntoolbar.cpp b/umbrello/umbrello/aligntoolbar.cpp
index 3aac8342..2ac38d4e 100644
--- a/umbrello/umbrello/aligntoolbar.cpp
+++ b/umbrello/umbrello/aligntoolbar.cpp
@@ -335,7 +335,7 @@ void AlignToolBar::slotButtonChanged(int btn) {
// at least 2 widgets must be selected
if (widgetList.count() > 1) {
// now perform alignment according to the clicked button
switch (btn) {
case alac_align_left:
alignLeft(widgetList);
@@ -380,7 +380,7 @@ void AlignToolBar::slotButtonChanged(int btn) {
UMLApp::app()->getDocument()->setModified();
} else {
KMessageBox::messageBox(0, KMessageBox::Information,
- i18n("For alignment you have to select at least 2 objects like classes or actors. You can not align associations."),
+ i18n("For tqalignment you have to select at least 2 objects like classes or actors. You can not align associations."),
i18n("Information"), i18n("&OK"), TQString(""),
"showAlignInformation");
} // if (widgetList.count() > 1)
@@ -335,7 +335,7 @@ void AlignToolBar::slotButtonChanged(int btn) {
// at least 2 widgets must be selected
if (widgetList.count() > 1) {
- // now perform alignment according to the clicked button
+ // now perform tqalignment according to the clicked button
switch (btn) {
case alac_align_left: